encode_writer

Function encode_writer 

pub const fn encode_writer<W: Write>(inner: W) -> EncodeWriter<W, 32> 
Creates an encoding writer that wraps an io::Write.\n\nThe writer buffers raw bytes, encodes them to base32_dns with padding, and writes the encoded output to the inner writer.\n\n# Examples\n\n\nuse omp_core::base32_dns;\nuse std::io::Write;\n\nlet mut output = Vec::new();\nlet mut writer = base32_dns::encode_writer(&mut output);\nwriter.write_all(b\"Hello\").unwrap();\nwriter.flush().unwrap();\n\n