pub struct AppendSlice<'a, T>(/* private fields */);Expand description
A slice-like view produced by AppendVec::slice.
Internally the vector is backed by multiple exponentially growing buckets.
An AppendSlice therefore stores a small SmallVec of slice
references so that the common case of spanning at most four buckets is
allocated on the stack.
The structure is copy-free and merely borrows the data. Two different iterator flavours are provided:
iter– borrows&selfand yields&Titems.IntoIterator– consumes the range and yields&Titems with the exact-size, fused iteratorAppendSliceIntoIter.
Implementations
Sourceimpl<'a, T> AppendSlice<'a, T>
impl<'a, T> AppendSlice<'a, T>
Sourcepub fn new(slices: &'a [&'a [T]]) -> Self
pub fn new(slices: &'a [&'a [T]]) -> Self
A view over slices presented as one contiguous sequence.
Sourcepub fn get(&self, index: usize) -> Option<&'a T>
pub fn get(&self, index: usize) -> Option<&'a T>
Returns a reference to the element at index, or None if the index is
out of bounds for this range.
Equivalent to self.into_iter().nth(index) but constant-time.
Sourcepub fn iter(&self) -> Iter<'_, T>
pub fn iter(&self) -> Iter<'_, T>
Returns an iterator over the elements in the range.
This is the same iterator that the &AppendSlice implementation of
IntoIterator returns.