Module cow_bytes

Module cow_bytes 

Clone-on-write byte slice with Bytes as the owned variant.

Provides a Cow-like type where the borrowed variant is &[u8] and the owned variant is Bytes, enabling cheap clones and zero-copy slicing when owned.

Enums

CowBytes
Clone-on-write byte slice with Bytes as the owned variant.